@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1994, 1995, 1996, 1997, 2002, 2004, 2005, 2006, 2007
-              John W. Eaton
+Copyright (C) 1994-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -22,7 +21,7 @@ along with Octave; see the file COPYING.  If not, see
 */
 
 #if !defined (octave_ComplexLU_h)
-#define octave_Complex_LU_h 1
+#define octave_ComplexLU_h 1
 
 #include "base-lu.h"
 #include "dMatrix.h"
@@ -30,33 +29,39 @@ along with Octave; see the file COPYING.  If not, see
 
 class
 OCTAVE_API
-ComplexLU : public base_lu <ComplexMatrix, Complex, Matrix, double>
+ComplexLU : public base_lu <ComplexMatrix>
 {
 public:
 
   ComplexLU (void)
-    : base_lu <ComplexMatrix, Complex, Matrix, double> () { }
+    : base_lu <ComplexMatrix> () { }
 
   ComplexLU (const ComplexMatrix& a);
 
   ComplexLU (const ComplexLU& a)
-    : base_lu <ComplexMatrix, Complex, Matrix, double> (a) { }
+    : base_lu <ComplexMatrix> (a) { }
+
+  ComplexLU (const ComplexMatrix& l, const ComplexMatrix& u,
+             const PermMatrix& p)
+    : base_lu <ComplexMatrix> (l, u, p) { }
 
   ComplexLU& operator = (const ComplexLU& a)
     {
       if (this != &a)
-	base_lu <ComplexMatrix, Complex, Matrix, double> :: operator = (a);
+        base_lu <ComplexMatrix> :: operator = (a);
 
       return *this;
     }
 
   ~ComplexLU (void) { }
+
+  void update (const ComplexColumnVector& u, const ComplexColumnVector& v);
+
+  void update (const ComplexMatrix& u, const ComplexMatrix& v);
+
+  void update_piv (const ComplexColumnVector& u, const ComplexColumnVector& v);
+
+  void update_piv (const ComplexMatrix& u, const ComplexMatrix& v);
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
