@@ -46,6 +46,13 @@ DiagArray2<T>::DiagArray2 (const Array<T>& a, octave_idx_type r,
     Array<T>::resize (dim_vector (rcmin, 1));
 }
 
+template <class T>
+Array<T>
+DiagArray2<T>::extract_diag (octave_idx_type k) const
+{
+  return diag (k);
+}
+
 template <class T>
 Array<T>
 DiagArray2<T>::diag (octave_idx_type k) const
@@ -82,18 +89,6 @@ DiagArray2<T>::hermitian (T (* fcn) (const T&)) const
 
 // A two-dimensional array with diagonal elements only.
 
-template <class T>
-T
-DiagArray2<T>::checkelem (octave_idx_type r, octave_idx_type c) const
-{
-  if (r < 0 || r >= dim1 ())
-    gripe_index_out_of_range (2, 1, r+1, dim1 ());
-  if (c < 0 || c >= dim2 ())
-    gripe_index_out_of_range (2, 2, c+1, dim2 ());
-
-  return elem (r, c);
-}
-
 template <class T>
 void
 DiagArray2<T>::resize (octave_idx_type r, octave_idx_type c,
@@ -123,3 +118,24 @@ DiagArray2<T>::array_value (void) const
 
   return result;
 }
+
+template <typename T>
+bool
+DiagArray2<T>::check_idx (octave_idx_type r, octave_idx_type c) const
+{
+  bool ok = true;
+
+  if (r < 0 || r >= dim1 ())
+    {
+      gripe_index_out_of_range (2, 1, r+1, dim1 ());
+      ok = false;
+    }
+
+  if (c < 0 || c >= dim2 ())
+    {
+      gripe_index_out_of_range (2, 2, c+1, dim2 ());
+      ok = false;
+    }
+
+  return ok;
+}
