@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1994, 1995, 1996, 1997, 2003, 2004, 2005, 2006, 2007
-              John W. Eaton
+Copyright (C) 1994-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -34,21 +33,32 @@ along with Octave; see the file COPYING.  If not, see
 #include "chMatrix.h"
 #include "dMatrix.h"
 #include "CMatrix.h"
+#include "fMatrix.h"
+#include "fCMatrix.h"
 
 // Column Vector classes.
 
 #include "dColVector.h"
 #include "CColVector.h"
+#include "fColVector.h"
+#include "fCColVector.h"
 
 // Row Vector classes.
 
 #include "dRowVector.h"
 #include "CRowVector.h"
+#include "fRowVector.h"
+#include "fCRowVector.h"
 
 // Diagonal Matrix classes.
 
 #include "dDiagMatrix.h"
 #include "CDiagMatrix.h"
+#include "fDiagMatrix.h"
+#include "fCDiagMatrix.h"
+
+// Permutation matrix class
+#include "PermMatrix.h"
 
 // Sparse Matrix classes.
 
@@ -62,6 +72,8 @@ along with Octave; see the file COPYING.  If not, see
 #include "chNDArray.h"
 #include "dNDArray.h"
 #include "CNDArray.h"
+#include "fNDArray.h"
+#include "fCNDArray.h"
 
 #include "int8NDArray.h"
 #include "int16NDArray.h"
@@ -74,9 +86,3 @@ along with Octave; see the file COPYING.  If not, see
 #include "uint64NDArray.h"
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
