@@ -78,7 +78,7 @@ oct_md5_file (const std::string file)
         (*current_liboctave_error_handler) ("internal error in md5_stream");
     }
   else
-    (*current_liboctave_error_handler) ("unable to open file `%s' for reading",
+    (*current_liboctave_error_handler) ("unable to open file '%s' for reading",
                                         file.c_str());
 
   return retval;
