@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2011 Sren Hauberg
+## Copyright (C) 2005-2012 Sren Hauberg
 ##
 ## This file is part of Octave.
 ##
@@ -19,12 +19,12 @@
 ## -*- texinfo -*-
 ## @deftypefn {Command} {} doc @var{function_name}
 ## Display documentation for the function @var{function_name}
-## directly from an on-line version of
+## directly from an online version of
 ## the printed manual, using the GNU Info browser.  If invoked without
 ## any arguments, the manual is shown from the beginning.
 ##
 ## For example, the command @kbd{doc rand} starts the GNU Info browser
-## at the @code{rand} node in the on-line version of the manual.
+## at the @code{rand} node in the online version of the manual.
 ##
 ## Once the GNU Info browser is running, help for using it is available
 ## using the command @kbd{C-h}.
@@ -92,7 +92,7 @@ function retval = doc (fname)
     if (! (have_fname && status == 0))
       status = system (cmd);
       if (status == 127)
-        warning ("unable to find info program `%s'", info_program ());
+        warning ("unable to find info program '%s'", info_program ());
       endif
     endif
 
