@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2011 Sren Hauberg
+## Copyright (C) 2005-2012 Sren Hauberg
 ##
 ## This file is part of Octave.
 ##
@@ -21,7 +21,7 @@
 ## @deftypefnx {Function File} {} unzip (@var{zipfile}, @var{dir})
 ## Unpack the ZIP archive @var{zipfile} to the directory @var{dir}.
 ## If @var{dir} is not specified, it defaults to the current directory.
-## @seealso{unpack, bunzip2, tar, untar, gzip, gunzip, zip}
+## @seealso{zip, unpack, bunzip2, gunzip, untar}
 ## @end deftypefn
 
 ## Author: Sren Hauberg <hauberg@gmail.com>
