@@ -2325,7 +2325,7 @@ function str = no_super_sub_scripts (str)
         n2 = setdiff (n2, n1);
       end
       for n = numel(n2):-1:1
-        labels{m} = [labels{m}(1:n2(n)-1), "\\", labels{m}(n2(n):end)]
+        labels{m} = [labels{m}(1:n2(n)-1), "\\", labels{m}(n2(n):end)];
       endfor
     endfor
   endfor
