@@ -42,9 +42,9 @@
 ## y = sin (x);
 ## plot (x, y, "ydatasource", "y");
 ## for i = 1 : 100
-##   pause(0.1)
-##   y = sin (x + 0.1 * i);
-##   refreshdata();
+##   pause (0.1);
+##   y = sin (x + 0.1*i);
+##   refreshdata ();
 ## endfor
 ## @end group
 ## @end example
