@@ -1,4 +1,4 @@
-## Copyright (C) 2007 Kai Habel, David Bateman
+## Copyright (C) 2007-2012 Kai Habel, David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,52 +17,59 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} slice (@var{x}, @var{y}, @var{z}, @var{v}, @var{sx}, @var{sy}, @var{sz})
+## @deftypefn  {Function File} {} slice (@var{x}, @var{y}, @var{z}, @var{v}, @var{sx}, @var{sy}, @var{sz})
 ## @deftypefnx {Function File} {} slice (@var{x}, @var{y}, @var{z}, @var{v}, @var{xi}, @var{yi}, @var{zi})
 ## @deftypefnx {Function File} {} slice (@var{v}, @var{sx}, @var{sy}, @var{sz})
 ## @deftypefnx {Function File} {} slice (@var{v}, @var{xi}, @var{yi}, @var{zi})
 ## @deftypefnx {Function File} {@var{h} =} slice (@dots{})
 ## @deftypefnx {Function File} {@var{h} =} slice (@dots{}, @var{method})
-## Plot slices of 3D data/scalar fields. Each element of the 3-dimensional 
+## Plot slices of 3-D data/scalar fields.  Each element of the 3-dimensional
 ## array @var{v} represents a scalar value at a location given by the
-## parameters @var{x}, @var{y}, and @var{z}. The parameters @var{x},
+## parameters @var{x}, @var{y}, and @var{z}.  The parameters @var{x},
 ## @var{x}, and @var{z} are either 3-dimensional arrays of the same size
-## as the array @var{v} in the "meshgrid" format or vectors. The
-## parameters @var{xi}, etc respect a similar format to @var{x}, etc,
+## as the array @var{v} in the "meshgrid" format or vectors.  The
+## parameters @var{xi}, etc. respect a similar format to @var{x}, etc.,
 ## and they represent the points at which the array @var{vi} is
-## interpolated using interp3. The vectors @var{sx}, @var{sy}, and
+## interpolated using interp3.  The vectors @var{sx}, @var{sy}, and
 ## @var{sz} contain points of orthogonal slices of the respective axes.
 ##
-## If @var{x}, @var{y}, @var{z} are omitted, they are assumed to be 
+## If @var{x}, @var{y}, @var{z} are omitted, they are assumed to be
 ## @code{x = 1:size (@var{v}, 2)}, @code{y = 1:size (@var{v}, 1)} and
-## @code{z = 1:size (@var{v}, 3)}. 
+## @code{z = 1:size (@var{v}, 3)}.
 ##
 ## @var{Method} is one of:
 ##
-## @table @code
+## @table @asis
 ## @item "nearest"
-## Return the nearest neighbour.
+## Return the nearest neighbor.
+##
 ## @item "linear"
-## Linear interpolation from nearest neighbours.
+## Linear interpolation from nearest neighbors.
+##
 ## @item "cubic"
-## Cubic interpolation from four nearest neighbours (not implemented yet).
+## Cubic interpolation from four nearest neighbors (not implemented yet).
+##
 ## @item "spline"
 ## Cubic spline interpolation---smooth first and second derivatives
 ## throughout the curve.
 ## @end table
 ##
 ## The default method is @code{"linear"}.
-## The optional return value @var{h} is a vector of handles to the
-## surface graphic objects.
+##
+## The optional return value @var{h} is a graphics handle to the created
+## surface object.
 ##
 ## Examples:
+##
 ## @example
+## @group
 ## [x, y, z] = meshgrid (linspace (-8, 8, 32));
 ## v = sin (sqrt (x.^2 + y.^2 + z.^2)) ./ (sqrt (x.^2 + y.^2 + z.^2));
 ## slice (x, y, z, v, [], 0, []);
 ## [xi, yi] = meshgrid (linspace (-7, 7));
 ## zi = xi + yi;
 ## slice (x, y, z, v, xi, yi, zi);
+## @end group
 ## @end example
 ## @seealso{interp3, surface, pcolor}
 ## @end deftypefn
@@ -102,7 +109,7 @@ function h = slice (varargin)
     elseif (ndims (x) == 3 && size_equal (x, y, z))
       ## Do nothing.
     else
-      error ("slice: X, Y, Z size mismatch")
+      error ("slice: X, Y, Z size mismatch");
     endif
     sx = varargin{5};
     sy = varargin{6};
@@ -133,7 +140,7 @@ function h = slice (varargin)
     if (length(sz) > 0)
       for i = 1:length(sz)
         [xi, yi, zi] = meshgrid (squeeze (x(1,:,1)),
-				 squeeze (y(:,1,1)), sz(i));
+                                 squeeze (y(:,1,1)), sz(i));
         vz = squeeze (interp3 (x, y, z, v, xi, yi, zi, method));
         tmp(sidx++) = surface (xi, yi, sz(i) * ones (size (yi)), vz);
       endfor
@@ -141,11 +148,11 @@ function h = slice (varargin)
 
     if (length (sy) > 0)
       for i = length(sy):-1:1
-	[xi, yi, zi] = meshgrid (squeeze (x(1,:,1)), sy(i), squeeze (z(1,1,:)));
+        [xi, yi, zi] = meshgrid (squeeze (x(1,:,1)), sy(i), squeeze (z(1,1,:)));
         vy = squeeze (interp3 (x, y, z, v, xi, yi, zi, method));
         tmp(sidx++) = surface (squeeze (xi),
-			       squeeze (sy(i) * ones (size (zi))),
-			       squeeze (zi), vy);
+                               squeeze (sy(i) * ones (size (zi))),
+                               squeeze (zi), vy);
       endfor
     endif
 
@@ -154,7 +161,7 @@ function h = slice (varargin)
         [xi, yi, zi] = meshgrid (sx(i), squeeze (y(:,1,1)), squeeze (z(1,1,:)));
         vx = squeeze (interp3 (x, y, z, v, xi, yi, zi, method));
         tmp(sidx++) = surface (squeeze (sx(i) * ones (size (zi))),
-			       squeeze (yi), squeeze(zi), vx);
+                               squeeze (yi), squeeze(zi), vx);
       endfor
     endif
   else
@@ -164,7 +171,7 @@ function h = slice (varargin)
 
   if (! ishold ())
     set (ax, "view", [-37.5, 30.0], "box", "off", "xgrid", "on",
-	 "ygrid", "on", "zgrid", "on");
+         "ygrid", "on", "zgrid", "on");
   endif
 
   if (nargout > 0)
@@ -173,10 +180,18 @@ function h = slice (varargin)
 
 endfunction
 
+
 %!demo
+%! clf
 %! [x, y, z] = meshgrid (linspace (-8, 8, 32));
 %! v = sin (sqrt (x.^2 + y.^2 + z.^2)) ./ (sqrt (x.^2 + y.^2 + z.^2));
 %! slice (x, y, z, v, [], 0, []);
+
+%!demo
+%! clf
+%! [x, y, z] = meshgrid (linspace (-8, 8, 32));
+%! v = sin (sqrt (x.^2 + y.^2 + z.^2)) ./ (sqrt (x.^2 + y.^2 + z.^2));
 %! [xi, yi] = meshgrid (linspace (-7, 7));
 %! zi = xi + yi;
 %! slice (x, y, z, v, xi, yi, zi);
+
