@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2006-2011 John W. Eaton
+Copyright (C) 2006-2012 John W. Eaton
 Copyright (C) 2010 VZLU Prague
 
 This file is part of Octave.
@@ -32,6 +32,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "file-stat.h"
 #include "oct-env.h"
 #include "pathsearch.h"
+#include "singleton-cleanup.h"
 
 #include "defaults.h"
 #include "defun.h"
@@ -290,7 +291,12 @@ load_path::instance_ok (void)
   bool retval = true;
 
   if (! instance)
-    instance = new load_path ();
+    {
+      instance = new load_path ();
+
+      if (instance)
+        singleton_cleanup_list::add (cleanup_instance);
+    }
 
   if (! instance)
     {
@@ -631,7 +637,7 @@ load_path::do_add (const std::string& dir_arg, bool at_end, bool warn)
 
   if (len > 1 && dir_arg.substr (len-2) == "//")
     warning_with_id ("Octave:recursive-path-search",
-                     "trailing `//' is no longer special in search path elements");
+                     "trailing '//' is no longer special in search path elements");
 
   std::string dir = file_ops::tilde_expand (dir_arg);
 
