@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2011 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -37,6 +37,7 @@ class octave_value_list;
 #include "data-conv.h"
 #include "lo-utils.h"
 #include "mach-info.h"
+#include "oct-refcount.h"
 
 class
 OCTINTERP_API
@@ -86,14 +87,14 @@ public:
   // TRUE if we are not storing the result of this conversion.
   bool discard;
 
-  // Type of conversion -- `d', `i', `o', `u', `x', `e', `f', `g',
-  // `c', `s', `p', `%', or `['.
+  // Type of conversion -- 'd', 'i', 'o', 'u', 'x', 'e', 'f', 'g',
+  // 'c', 's', 'p', '%', or '['.
   char type;
 
-  // A length modifier -- `h', `l', or `L'.
+  // A length modifier -- 'h', 'l', or 'L'.
   char modifier;
 
-  // The class of characters in a `[' format.
+  // The class of characters in a '[' format.
   std::string char_class;
 };
 
@@ -228,14 +229,14 @@ public:
   // Precision.
   int prec;
 
-  // Flags -- `-', `+', ` ', `0', or `#'.
+  // Flags -- '-', '+', ' ', '0', or '#'.
   std::string flags;
 
-  // Type of conversion -- `d', `i', `o', `x', `X', `u', `c', `s',
-  // `f', `e', `E', `g', `G', `p', or `%'
+  // Type of conversion -- 'd', 'i', 'o', 'x', 'X', 'u', 'c', 's',
+  // 'f', 'e', 'E', 'g', 'G', 'p', or '%'
   char type;
 
-  // A length modifier -- `h', `l', or `L'.
+  // A length modifier -- 'h', 'l', or 'L'.
   char modifier;
 };
 
@@ -427,7 +428,7 @@ protected:
 private:
 
   // A reference count.
-  octave_idx_type count;
+  octave_refcount<octave_idx_type> count;
 
   // The permission bits for the file.  Should be some combination of
   // std::ios::open_mode bits.
@@ -689,6 +690,8 @@ private:
 
   static octave_stream_list *instance;
 
+  static void cleanup_instance (void) { delete instance; instance = 0; }
+
   int do_insert (octave_stream& os);
 
   octave_stream do_lookup (int fid, const std::string& who = std::string ()) const;
