@@ -1263,7 +1263,7 @@ octave_base_value::dump (std::ostream& os) const
 static void
 gripe_indexed_assignment (const std::string& tn1, const std::string& tn2)
 {
-  error ("assignment of `%s' to indexed `%s' not implemented",
+  error ("assignment of '%s' to indexed '%s' not implemented",
          tn2.c_str (), tn1.c_str ());
 }
 
@@ -1271,7 +1271,7 @@ static void
 gripe_assign_conversion_failed (const std::string& tn1,
                                 const std::string& tn2)
 {
-  error ("type conversion for assignment of `%s' to indexed `%s' failed",
+  error ("type conversion for assignment of '%s' to indexed '%s' failed",
          tn2.c_str (), tn1.c_str ());
 }
 
@@ -1279,7 +1279,7 @@ static void
 gripe_no_conversion (const std::string& on, const std::string& tn1,
                      const std::string& tn2)
 {
-  error ("operator %s: no conversion for assignment of `%s' to indexed `%s'",
+  error ("operator %s: no conversion for assignment of '%s' to indexed '%s'",
          on.c_str (), tn2.c_str (), tn1.c_str ());
 }
 
